@@ -1,5 +1,5 @@
 from .release import __version__
-from .generate import generate
+from .generate import generate, mark_dirty, dirty, clean
 from .exceptions import ParsimonyException
 
 from . import generators
